@@ -8,6 +8,9 @@ knitr::opts_chunk$set(
 library(hereR)
 set_key("<YOUR API KEY>")
 
+## ----set_verbose--------------------------------------------------------------
+set_verbose(TRUE)
+
 ## ----proxy--------------------------------------------------------------------
 set_proxy(
   proxy = "https://<YOUR-PROXY.NET>:<PORT>/",
