@@ -6,8 +6,8 @@ test_that("isoline works", {
   data(poi)
 
   # Input checks
-  expect_error(isoline(poi = c(1, 2, 3)), "'points' must be an sf object.")
-  expect_error(isoline(poi = c("character", NA)), "'points' must be an sf object.")
+  expect_error(isoline(poi = c(1, 2, 3)), "'poi' must be an sf object.")
+  expect_error(isoline(poi = c("character", NA)), "'poi' must be an sf object.")
   expect_error(isoline(poi = poi, mode = "not_a_mode"))
   expect_error(isoline(poi = poi, type = "not_a_type"))
   expect_error(isoline(poi = poi, range_type = "not_a_range_type"))
